<?php
namespace App\Admin\Controllers;
use App\Admin\Repositories\ListYun;
use Dcat\Admin\Form;
use Dcat\Admin\Grid;
use Dcat\Admin\Http\Controllers\AdminController;
use Dcat\Admin\Show;

class ListYunController extends AdminController {
	/**
	 * Make a grid builder.
	 *
	 * @return Grid
	 */
	protected function grid() {
		return Grid::make(new ListYun(), function (Grid $grid) {
			$grid->column('id')->sortable();
			$grid->column('title');
			// $grid->column('content');
			$grid->column('type')->using(admin_trans('list-yun.options.type'))->sortable();
			$grid->column('town')->using(admin_trans('list-yun.options.town'));

			// $grid->column('town')->editable();
			$grid->column('imgs')->display(function ($v) {
				return explode(',', $v)[0];
			})->image();
			// $grid->column('sort');
			// $grid->column('live');
			// $grid->column('add_x');
			// $grid->column('add_y');
			$grid->column('show')->switch();
			$grid->column('created_at');
			$grid->column('updated_at')->sortable();
			$grid->filter(function (Grid\Filter $filter) {
				$filter->like('title');
			});
		});
	}
	/**
	 * Make a show builder.
	 *
	 * @param mixed $id
	 *
	 * @return Show
	 */
	protected function detail($id) {
		return Show::make($id, new ListYun(), function (Show $show) {
			$show->field('id');
			$show->field('title');
			$show->field('content');
			$show->field('type');
			$show->field('imgs');
			$show->field('sort');
			$show->field('live');
			$show->field('add_x');
			$show->field('add_y');
			$show->field('created_at');
			$show->field('updated_at');
		});
	}
	/**
	 * Make a form builder.
	 *
	 * @return Form
	 */
	protected function form() {
		return Form::make(new ListYun(), function (Form $form) {
			$form->hidden('id');
			$form->text('title')->required();
			$form->textarea('content')->help('请填写简介建议字数不超过200字');
			$form->select('type')->options(admin_trans('list-yun.options.type'))->required();
			$form->select('town')->options(admin_trans('list-yun.options.town'))->required();
			$form->multipleImage('imgs')->sortable()->saving(function ($v) {return implode(',', $v);});
			$form->text('live');
			$form->file('video')->maxSize(1024 * 30)->help('如无远程地址请上传视频,请勿超过30M');
			$form->text('add_x');
			$form->text('add_y');
			$form->map('add_x', 'add_y', '请标注位置');
			// $form->text('sort');
			$form->switch('show');
			$form->display('created_at');
			$form->display('updated_at');
		});
	}
}